@@ -12,7 +12,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric once );
 
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitExplicitReturnUndef)
@@ -128,7 +128,7 @@ END {
    MCE::Step::finish(1)   if $INC{'MCE/Step.pm'};
    MCE::Stream::finish(1) if $INC{'MCE/Stream.pm'};
 
-   MCE::Shared::stop();
+   _stop();
 }
 
 {
@@ -2345,7 +2345,7 @@ MCE::Shared::Server - Server/Object packages for MCE::Shared
 
 =head1 VERSION
 
-This document describes MCE::Shared::Server version 1.003
+This document describes MCE::Shared::Server version 1.004
 
 =head1 DESCRIPTION
 
